==> boost-docs-1.84.0.tgz: share/doc/boost/libs/redis/doc/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Boost.Redis", "index.html", [
    [ "Connection", "index.html#autotoc_md1", [
      [ "Server pushes", "index.html#autotoc_md2", null ]
    ] ],
    [ "Requests", "index.html#autotoc_md3", [
      [ "Config flags", "index.html#autotoc_md4", null ]
    ] ],
    [ "Responses", "index.html#autotoc_md5", [
      [ "Pushes", "index.html#autotoc_md6", null ],
      [ "Null", "index.html#autotoc_md7", null ],
      [ "Transactions", "index.html#autotoc_md8", null ],
      [ "The general case", "index.html#autotoc_md9", null ]
    ] ],
    [ "Serialization", "index.html#autotoc_md10", null ],
    [ "Examples", "index.html#autotoc_md11", null ],
    [ "Echo server benchmark", "index.html#autotoc_md12", [
      [ "Without Redis", "index.html#autotoc_md13", null ],
      [ "With Redis", "index.html#autotoc_md14", null ],
      [ "Conclusion", "index.html#autotoc_md15", null ]
    ] ],
    [ "Comparison", "index.html#autotoc_md16", [
      [ "Boost.Redis vs Redis-plus-plus", "index.html#autotoc_md17", null ]
    ] ],
    [ "Reference", "index.html#autotoc_md18", null ],
    [ "Acknowledgement", "index.html#autotoc_md19", null ],
    [ "Changelog", "index.html#autotoc_md20", [
      [ "develop", "index.html#autotoc_md21", null ],
      [ "v1.4.2 (incorporates changes to conform the boost review and more)", "index.html#autotoc_md22", null ],
      [ "v1.4.0-1", "index.html#autotoc_md23", null ],
      [ "v1.3.0-1", "index.html#autotoc_md24", null ],
      [ "v1.2.0", "index.html#autotoc_md25", null ],
      [ "v1.1.0-1", "index.html#autotoc_md26", null ],
      [ "v1.0.0", "index.html#autotoc_md27", null ],
      [ "v0.3.0", "index.html#autotoc_md28", null ],
      [ "v0.2.0-1", "index.html#autotoc_md29", null ],
      [ "v0.1.0-2", "index.html#autotoc_md30", null ],
      [ "v0.0.1", "index.html#autotoc_md31", null ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"index.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> boost-docs-1.86.0.tgz: share/doc/boost/libs/redis/doc/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Boost.Redis", "index.html", [
    [ "Connection", "index.html#autotoc_md1", [
      [ "Server pushes", "index.html#autotoc_md2", null ]
    ] ],
    [ "Requests", "index.html#autotoc_md3", [
      [ "Config flags", "index.html#autotoc_md4", null ]
    ] ],
    [ "Responses", "index.html#autotoc_md5", [
      [ "Pushes", "index.html#autotoc_md6", null ],
      [ "Null", "index.html#autotoc_md7", null ],
      [ "Transactions", "index.html#autotoc_md8", null ],
      [ "The general case", "index.html#autotoc_md9", null ]
    ] ],
    [ "Serialization", "index.html#autotoc_md10", null ],
    [ "Examples", "index.html#autotoc_md11", null ],
    [ "Echo server benchmark", "index.html#autotoc_md12", [
      [ "Without Redis", "index.html#autotoc_md13", null ],
      [ "With Redis", "index.html#autotoc_md14", null ],
      [ "Conclusion", "index.html#autotoc_md15", null ]
    ] ],
    [ "Comparison", "index.html#autotoc_md16", [
      [ "Boost.Redis vs Redis-plus-plus", "index.html#autotoc_md17", null ]
    ] ],
    [ "Reference", "index.html#autotoc_md18", null ],
    [ "Acknowledgement", "index.html#autotoc_md19", null ],
    [ "Changelog", "index.html#autotoc_md20", [
      [ "Boost 1.85", "index.html#autotoc_md21", null ],
      [ "Boost 1.84 (First release in Boost)", "index.html#autotoc_md22", null ],
      [ "v1.4.2 (incorporates changes to conform the boost review and more)", "index.html#autotoc_md23", null ],
      [ "v1.4.0-1", "index.html#autotoc_md24", null ],
      [ "v1.3.0-1", "index.html#autotoc_md25", null ],
      [ "v1.2.0", "index.html#autotoc_md26", null ],
      [ "v1.1.0-1", "index.html#autotoc_md27", null ],
      [ "v1.0.0", "index.html#autotoc_md28", null ],
      [ "v0.3.0", "index.html#autotoc_md29", null ],
      [ "v0.2.0-1", "index.html#autotoc_md30", null ],
      [ "v0.1.0-2", "index.html#autotoc_md31", null ],
      [ "v0.0.1", "index.html#autotoc_md32", null ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"index.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
